#!/bin/bash
set -e

err() {
  printf "\033[0;31m%s\n\033[0m" "$*" >&2;
}
step () {
  python3 -c "text='$2'; desc=' {}'.format(text) if text else ''; print('\033[0;33;49m{}\033[0m ({:02}{}) \033[0;33;49m{}\033[0m'.format('-' * 8, $1, desc, '-' * (80 - len(desc))))"
}

export CONAN_HOME="$PWD/conan_cache"
mkdir -p "$CONAN_HOME"

echo 'This is a C++ executable template.'
echo 'It allows you run `build_and_run.sh` repeatedly after `run_once.sh` to build an executable.'
echo 'It uses Conan and CMake:'
echo '  • Conan is a dependency and package manager for C and C++ languages.'
echo '  • CMake is a tool to manage building of source code.'
echo

# (1) install conan as python package in a virtual environment
step 1 "install conan from PyPI"
python3 -m venv venv
source ./venv/bin/activate
./venv/bin/pip3 install conan --upgrade
./venv/bin/conan profile detect --force

# (2) install cmake
step 2 "install cmake via apt"
#if [ "$EUID" -ne 0 ]; then
#  err "Please run as root"
#  exit
#fi
echo "install cmake via apt"
#install cmake

# (3) inform user about TODO flags
step 3 "inform user"
echo 'WARN: there are several TODO flags in the codebase'
echo '      please fix them and then run `build_and_run.sh`'
grep --color=always --directories=skip --exclude="$BASH_SOURCE" -n TODO ./*

echo
echo "done."
